extensions [sound]
breed [humans human]
breed [robots robot]
turtles-own [dead]
globals [  thehuman door-closed? level entrance starty ]

to setup
  clear-patches
  set level 0
  set nb-robots 0
  set entrance []
  setup-level
  ask patches with [count neighbors != 8] [set pcolor white]
end

to setup-level
  clear-turtles
  create_player
  create_ennemies
  ask turtles [set dead false]
  set door-closed? true
  foreach entrance [ask ? [set pcolor  black]]  
end

to create_player
  create-humans 1 
  [
    set shape "person" 
    set color white 
    set size 2 
    set thehuman self
    ;setxy xcor oldy
  ]
end

to create_ennemies
  create-robots nb-robots 
  [
    set shape "turtle" 
    setxy (max-pxcor - 1 - random 10)random-ycor 
    set color white 
    set size 2
  ]
end


to load-levelmap
  let levelbackup level
  let entrancebackup entrance
  if level != 0 
  [
    run (word "import-world \"maps/nobots_map" level  ".csv\"")
  ]
  set level levelbackup
  set entrance entrancebackup
end


to go [direction]

  go-human direction 
  go-robots
  
  if not any? robots with [dead = false]
  [
    if door-closed? [
      open-door
      set door-closed? false
      ]
  ]

end

to go-human [direction]
  ask thehuman
  [
    ifelse any? robots-here with [dead = false] 
    [become-dead]
    [
      if direction != 0   ; if direction = 0 that means stay where you are. To go up, use 360.
      [ set heading direction
        if not ([pcolor] of patch-ahead 1 = white )[fd 1]
      ]
    ]
  ]
  if human-died? [
    let oldy starty
    wait 1
    setup-level
    set starty oldy
    ask thehuman [
      show (word "my new ycor will be " starty)
      setxy min-pxcor starty
    ]
  ]
  
  ; this is only possible if thehuman reaches the entrance
  if [pxcor] of thehuman = max-pxcor [
    let oldy ([ycor] of thehuman)
    show (word "old coordinates " [xcor] of thehuman " " [ycor] of thehuman)
    level-up
    setup-level
    set starty oldy
    ask thehuman 
    [
      setxy min-pxcor starty
      show (word "new coordinates " xcor " " ycor)
    ]
  ]
end

to go-robots
  ask robots with [dead = false] 
  [   
    face thehuman 
    fd 1
    if (any? other robots-here) or (pcolor = white) [become-dead]
  ]
  
end

to-report human-died?
  report [dead] of thehuman = true
end


to become-dead
  set shape "x"
  set dead true
  sound:play-sound "audio/test.wav"
end

to level-up
  sound:play-sound "audio/ghost.wav"  
  set nb-robots nb-robots + 3
  show (word "level was " level)
  set level (level + 1)
  show (word "level is now " level)
  load-levelmap

end

to open-door
  sound:play-sound "audio/info.wav"
  set entrance []
  ask one-of patches with [(pxcor = max-pxcor) and (pycor > min-pycor + 5) and (pycor < max-pycor - 5)]
  [
    set entrance lput (patch min-pxcor [pycor] of self) entrance
    set pcolor black
    foreach [1 2 3 4 5]
    [
      let thepatch patch-at 0 ?
      ask thepatch [set pcolor black]
      set entrance lput (patch min-pxcor [pycor] of thepatch) entrance
    ]
  ]
end


to go-up 
  go 360
end

to go-upright
  go 45
end

to go-right
  go 90
end

to go-downright
  go 135
end

to go-down
  go 180
end

to go-downleft
  go 225
end

to go-left
  go 270
end

to go-upleft
  go 315
end

to draw-obstacles
  draw white
end

to remove-obstacles
  draw black
end

to draw [thecolor]
    if mouse-down?
  [
    ask patch mouse-xcor mouse-ycor
    [ set pcolor thecolor]
  ]    
end
@#$#@#$#@
GRAPHICS-WINDOW
8
10
408
431
32
32
6.0
1
10
1
1
1
0
0
0
1
-32
32
-32
32
0
0
1
ticks
30.0

INPUTBOX
609
67
674
127
nb-robots
12
1
0
Number

BUTTON
609
24
672
57
NIL
setup
NIL
1
T
OBSERVER
NIL
R
NIL
NIL
1

BUTTON
685
219
753
252
UP
go-up
NIL
1
T
OBSERVER
NIL
8
NIL
NIL
1

BUTTON
812
219
875
252
UR
go-upright
NIL
1
T
OBSERVER
NIL
9
NIL
NIL
1

BUTTON
579
225
642
258
UL
go-upleft
NIL
1
T
OBSERVER
NIL
7
NIL
NIL
1

BUTTON
578
273
641
306
left
go-left
NIL
1
T
OBSERVER
NIL
4
NIL
NIL
1

BUTTON
812
268
875
301
right
go-right
NIL
1
T
OBSERVER
NIL
6
NIL
NIL
1

BUTTON
687
319
754
352
down
go-down
NIL
1
T
OBSERVER
NIL
2
NIL
NIL
1

BUTTON
814
311
877
344
DR
go-downright
NIL
1
T
OBSERVER
NIL
3
NIL
NIL
1

BUTTON
578
321
641
354
DL
go-downleft
NIL
1
T
OBSERVER
NIL
1
NIL
NIL
1

BUTTON
645
273
802
306
stay where you are
go 0
NIL
1
T
OBSERVER
NIL
5
NIL
NIL
1

BUTTON
697
23
849
56
NIL
draw-obstacles
T
1
T
OBSERVER
NIL
D
NIL
NIL
1

BUTTON
697
62
848
95
NIL
remove-obstacles
T
1
T
OBSERVER
NIL
X
NIL
NIL
1

MONITOR
609
131
675
176
NIL
level
17
1
11

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -7500403 true true 135 285 195 285 270 90 30 90 105 285
Polygon -7500403 true true 270 90 225 15 180 90
Polygon -7500403 true true 30 90 75 15 120 90
Circle -1 true false 183 138 24
Circle -1 true false 93 138 24

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
